#!/usr/bin/env bash

# SPDX-FileCopyrightText: Copyright (c) 2023-2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

set -euxo pipefail

SCRIPT=$(readlink -f $0)
HERE=$(dirname $SCRIPT)

if [ -z "$DEVTOOL_DIR" ] || [ -z "$DEVTOOL_CMD" ]; then
    echo "Error: Both DEVTOOL_DIR and DEVTOOL_CMD must be set to map a devtool into the container and have it auto-start!" >&2
else
    DEVTOOL_CMD=$(echo "$DEVTOOL_CMD" | sed "s/^\([\"']\)\(.*\)\1$/\2/g")
    "$DEVTOOL_DIR"/$DEVTOOL_CMD
fi
